/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect } from 'react';
import { Grid } from '@material-ui/core';
import styled from 'styled-components';
import Rating from '@material-ui/lab/Rating';
import IconButton from '@material-ui/core/IconButton';
import StarBorderIcon from '@material-ui/icons/StarBorder';
import FavoriteIcon from '@material-ui/icons/Favorite';
import InfoIcon from '@material-ui/icons/Info';
import axios from 'axios';
import { apiUrl } from '../env';
import ReportModal from './ReportModal.js';

export default function CollectionReview(props) {
	//TODO: chamar o modal de report
	const likes = 2;
	const [liked, setLiked] = useState(false);
	const [stars, setStars] = useState(0);
	const [reportOpen, setReportOpen] = useState(false);

	const handleClickReport = () => {
		setReportOpen(true);
	}
	
	const handleLikeClick = () => {
		const url = apiUrl+'/collections/'+props.id+'/like';
		if (liked)
			axios.put(url);
		else
			axios.delete(url);
		setLiked(!liked);
	}

	const handleSetStars = (value) => {
		setStars(value);
		props.scrollToComment();
	}

	const handleCloseModal = () => {
		setReportOpen(false);
	}

	return (
		<Grid container direction="row" justify="center" alignItems="center">
			<Grid item sm={8}>
				<Rating
				 name="customized-empty"
				 value={stars}
				 onChange={(e, value) => handleSetStars(value)}
				 precision={0.5}
				 style={{color:"#666"}}
				 emptyIcon={<StarBorderIcon fontSize="inherit" />}
				/>
			</Grid>
			<Grid item sm={4}>
				<IconButton aria-label="like" onClick={handleLikeClick}>
					{likes + (liked ? 1 : 0)}<FavoriteIcon />
				</IconButton>
			</Grid>
			<Grid item sm={12}>
				<IconButton 
					aria-label="report" 
					style={{fontSize: 'small'}}
					onClick={handleClickReport}>
					<InfoIcon />Reportar erro ou abuso
				</IconButton>
				<ReportModal
					open={reportOpen}
					handleClose={handleCloseModal}
					form="colecao"
					complainableId={props.id}
					complainableType="Collection"
				/>
			</Grid>

		</Grid>
	);
}
